[![Documentation Status](https://readthedocs.org/projects/prognosais/badge/?version=latest)](https://prognosais.readthedocs.io/en/latest/?badge=latest) [![codecov](https://codecov.io/gh/Svdvoort/prognosais/branch/master/graph/badge.svg?token=HTHVINR6Y8)](https://codecov.io/gh/Svdvoort/prognosais) [![Python test](https://github.com/Svdvoort/prognosais/workflows/Python%20test/badge.svg)](https://github.com/Svdvoort/prognosais/actions?query=workflow%3A%22Python+test%22)[![CodeFactor](https://www.codefactor.io/repository/github/svdvoort/prognosais/badge)](https://www.codefactor.io/repository/github/svdvoort/prognosais)[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Dependabot](https://flat.badgen.net/dependabot/Svdvoort/prognosais?icon=dependabot)](https://github.com/Svdvoort/prognosais/pulls?q=is%3Aopen+is%3Apr+label%3Adependencies)

# prognosais

prognosais is a tool to quickly prototype some CNNs for medical classification and segmentations tasks.
Please read the documentation: https://prognosais.readthedocs.io/en/latest/?badge=latest
